@@ -381,8 +381,8 @@ class Float(Trafaret):
 
     __metaclass__ = NumberMeta
 
-    value_type = float
     convertable = str_types + (numbers.Real,)
+    value_type = float
 
     def __init__(self, gte=None, lte=None, gt=None, lt=None):
         self.gte = gte
@@ -390,16 +390,18 @@ class Float(Trafaret):
         self.gt = gt
         self.lt = lt
 
+    def _converter(self, val):
+        if not isinstance(val, self.convertable):
+            self._failure('value is not %s' % self.value_type.__name__)
+        try:
+            return self.value_type(val)
+        except ValueError:
+            self._failure("value can't be converted to %s" %
+                          self.value_type.__name__)
+
     def _check_val(self, val):
         if not isinstance(val, self.value_type):
-            if isinstance(val, self.convertable):
-                try:
-                    value = self.value_type(val)
-                except ValueError:
-                    self._failure("value cant be converted to %s" %
-                            self.value_type.__name__)
-            else:
-                self._failure("value is not %s" % self.value_type.__name__)
+            value = self._converter(val)
         else:
             value = val
         if self.gte is not None and value < self.gte:
@@ -438,13 +440,19 @@ class Int(Float):
     >>> Int().check(5)
     5
     >>> extract_error(Int(), 1.1)
-    1
+    'value is not int'
     >>> extract_error(Int(), 1 + 1j)
     'value is not int'
     """
 
     value_type = int
 
+    def _converter(self, val):
+        if isinstance(val, float):
+            if not val.is_integer():
+                self._failure('value is not int')
+        return super(Int, self)._converter(val)
+
 
 class Atom(Trafaret):
 
@@ -653,7 +661,7 @@ class List(Trafaret):
     >>> extract_error(List(Int, max_length=2), [1, 2, 3])
     'list length is greater than 2'
     >>> extract_error(List(Int), ["a"])
-    {0: 'value cant be converted to int'}
+    {0: "value can't be converted to int"}
     """
 
     __metaclass__ = SquareBracketsMeta
@@ -769,11 +777,19 @@ class Dict(Trafaret):
     >>> trafaret = Dict({Key('bar', default='nyanya') >> 'baz': String}, foo=Int)
     >>> trafaret.check({'foo': 4})
     {'foo': 4, 'baz': 'nyanya'}
+    >>> _ = trafaret.ignore_extra('fooz')
+    >>> trafaret.check({'foo': 4, 'fooz': 5})
+    {'foo': 4, 'baz': 'nyanya'}
+    >>> _ = trafaret.ignore_extra('*')
+    >>> trafaret.check({'foo': 4, 'foor': 5})
+    {'foo': 4, 'baz': 'nyanya'}
     """
 
     def __init__(self, keys={}, **trafarets):
         self.extras = []
         self.allow_any = False
+        self.ignore = []
+        self.ignore_any = False
         self.keys = []
         for key, trafaret in itertools.chain(trafarets.items(), keys.items()):
             key_ = key if isinstance(key, Key) else Key(key)
@@ -788,6 +804,14 @@ class Dict(Trafaret):
                 self.extras.append(name)
         return self
 
+    def ignore_extra(self, *names):
+        for name in names:
+            if name == "*":
+                self.ignore_any = True
+            else:
+                self.ignore.append(name)
+        return self
+
     def make_optional(self, *args):
         for key in self.keys:
             if key.name in args or '*' in args:
@@ -805,11 +829,14 @@ class Dict(Trafaret):
                     errors[k] = v
                 else:
                     collect[k] = v
-        for key in data:
-            if not self.allow_any and key not in self.extras:
-                errors[key] = DataError("%s is not allowed key" % key)
-            else:
-                collect[key] = data
+        if not self.ignore_any:
+            for key in data:
+                if key in self.ignore:
+                    continue
+                if not self.allow_any and key not in self.extras:
+                    errors[key] = DataError("%s is not allowed key" % key)
+                else:
+                    collect[key] = data
         if errors:
             raise DataError(error=errors)
         return collect
@@ -824,6 +851,8 @@ class Dict(Trafaret):
         options = []
         if self.allow_any:
             options.append("any")
+        if self.ignore:
+            options.append("ignore=(%s)" % (", ".join(self.ignore)))
         if self.extras:
             options.append("extras=(%s)" % (", ".join(self.extras)))
         r += ", ".join(options)
@@ -848,7 +877,7 @@ class Mapping(Trafaret):
     >>> extract_error(trafaret, {"foo": 1, "bar": None})
     {'bar': {'value': 'value is not int'}}
     >>> extract_error(trafaret, {"foo": 1, 2: "bar"})
-    {2: {'key': 'value is not string', 'value': 'value cant be converted to int'}}
+    {2: {'key': 'value is not string', 'value': "value can't be converted to int"}}
     """
 
     def __init__(self, key, value):
