@@ -17,6 +17,8 @@ class KeysSubset(Key):
     >>> join = (lambda d: {'name': ' '.join(get_values(d, ['name', 'last']))})
     >>> Dict({KeysSubset('name', 'last'): join}).check({'name': 'Adam', 'last': 'Smith'})
     {'name': 'Adam Smith'}
+    >>> Dict({KeysSubset(): Dict({'a': Any})}).check({'a': 3})
+    {'a': 3}
     """
 
     def __init__(self, *keys):
@@ -25,12 +27,16 @@ class KeysSubset(Key):
         self.trafaret = Any()
 
     def pop(self, data):
-        subdict = dict((k, data.pop(k)) for k in self.keys if k in data)
+        subdict = dict((k, data.pop(k)) for k in self.keys_names() if k in data)
         res = catch_error(self.trafaret, subdict)
         if isinstance(res, DataError):
             res = res.error
         for k, v in res.items():
             yield k, v
 
-
-
+    def keys_names(self):
+        if isinstance(self.trafaret, Dict):
+            for key in self.trafaret.keys_names():
+                yield key
+        for key in self.keys:
+            yield key
